==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/entitysafetydefault_001/SafetyReviewDetail.java <==

package net.datastream.schemas.mp_entities.entitysafetydefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ESIGNATURE_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVIEWEDBYESIGN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREVIEWED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREVIEWREQUIRED" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "reviewedbyesign",
    "datereviewed",
    "datereviewrequired"
})
@XmlRootElement(name = "SafetyReviewDetail")
public class SafetyReviewDetail {

    @XmlElement(name = "REVIEWEDBYESIGN", namespace = "http://schemas.datastream.net/MP_fields")
    protected ESIGNATURE_Type reviewedbyesign;
    @XmlElement(name = "DATEREVIEWED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME datereviewed;
    @XmlElement(name = "DATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME datereviewrequired;

    /**
     * Obtient la valeur de la propriété reviewedbyesign.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public ESIGNATURE_Type getREVIEWEDBYESIGN() {
        return reviewedbyesign;
    }

    /**
     * Définit la valeur de la propriété reviewedbyesign.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public void setREVIEWEDBYESIGN(ESIGNATURE_Type value) {
        this.reviewedbyesign = value;
    }

    /**
     * Obtient la valeur de la propriété datereviewed.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREVIEWED() {
        return datereviewed;
    }

    /**
     * Définit la valeur de la propriété datereviewed.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREVIEWED(DATETIME value) {
        this.datereviewed = value;
    }

    /**
     * Obtient la valeur de la propriété datereviewrequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREVIEWREQUIRED() {
        return datereviewrequired;
    }

    /**
     * Définit la valeur de la propriété datereviewrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREVIEWREQUIRED(DATETIME value) {
        this.datereviewrequired = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/entitysafetydefault_001/SafetyReviewDetail.java <==

package net.datastream.schemas.mp_entities.entitysafetydefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ESIGNATURE_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVIEWEDBYESIGN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREVIEWED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREVIEWREQUIRED" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "reviewedbyesign",
    "datereviewed",
    "datereviewrequired"
})
@XmlRootElement(name = "SafetyReviewDetail")
public class SafetyReviewDetail {

    @XmlElement(name = "REVIEWEDBYESIGN", namespace = "http://schemas.datastream.net/MP_fields")
    protected ESIGNATURE_Type reviewedbyesign;
    @XmlElement(name = "DATEREVIEWED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME datereviewed;
    @XmlElement(name = "DATEREVIEWREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME datereviewrequired;

    /**
     * Gets the value of the reviewedbyesign property.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public ESIGNATURE_Type getREVIEWEDBYESIGN() {
        return reviewedbyesign;
    }

    /**
     * Sets the value of the reviewedbyesign property.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE_Type }
     *     
     */
    public void setREVIEWEDBYESIGN(ESIGNATURE_Type value) {
        this.reviewedbyesign = value;
    }

    /**
     * Gets the value of the datereviewed property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREVIEWED() {
        return datereviewed;
    }

    /**
     * Sets the value of the datereviewed property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREVIEWED(DATETIME value) {
        this.datereviewed = value;
    }

    /**
     * Gets the value of the datereviewrequired property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREVIEWREQUIRED() {
        return datereviewrequired;
    }

    /**
     * Sets the value of the datereviewrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREVIEWREQUIRED(DATETIME value) {
        this.datereviewrequired = value;
    }

}
